/**
 * Gets a stored Blob file by digest.
 *
 * @param {import('../types.js').InvocationConfig} conf Configuration
 * for the UCAN invocation. An object with `issuer`, `with` and `proofs`.
 *
 * The `issuer` is the signing authority that is issuing the UCAN
 * invocation(s). It is typically the user _agent_.
 *
 * The `with` is the resource the invocation applies to. It is typically the
 * DID of a space.
 *
 * The `proofs` are a set of capability delegations that prove the issuer
 * has the capability to perform the action.
 *
 * The issuer needs the `blob/get/0/1` delegated capability.
 * @param {import('multiformats').MultihashDigest} multihash of the blob
 * @param {import('../types.js').RequestOptions} [options]
 */
export function get({ issuer, with: resource, proofs, audience }: import('../types.js').InvocationConfig, multihash: import('multiformats').MultihashDigest, options?: import("../types.js").RequestOptions | undefined): Promise<{
    error?: undefined;
} & {
    ok: import("@web3-storage/capabilities/types").BlobGetSuccess;
}>;
/** Returns the ability used by an invocation. */
export const ability: "space/blob/get/0/1";
export function input(digest: import('multiformats').MultihashDigest): {
    digest: Uint8Array;
};
//# sourceMappingURL=get.d.ts.map