/**
 * Register an "index" with the service. The issuer needs the `index/add`
 * delegated capability.
 *
 * Required delegated capability proofs: `index/add`
 *
 * @param {import('../types.js').InvocationConfig} conf Configuration
 * for the UCAN invocation. An object with `issuer`, `with` and `proofs`.
 *
 * The `issuer` is the signing authority that is issuing the UCAN
 * invocation(s). It is typically the user _agent_.
 *
 * The `with` is the resource the invocation applies to. It is typically the
 * DID of a space.
 *
 * The `proofs` are a set of capability delegations that prove the issuer
 * has the capability to perform the action.
 *
 * The issuer needs the `index/add` delegated capability.
 * @param {import('../types.js').CARLink} index Index to store.
 * @param {import('../types.js').RequestOptions} [options]
 * @returns {Promise<import('../types.js').IndexAddSuccess>}
 */
export function add({ issuer, with: resource, proofs, audience }: import('../types.js').InvocationConfig, index: import('../types.js').CARLink, options?: import("../types.js").RequestOptions | undefined): Promise<import('../types.js').IndexAddSuccess>;
/** Returns the ability used by an invocation. */
export const ability: "space/index/add";
export function input(index: import('../types.js').CARLink): {
    index: import("@web3-storage/capabilities/types").CARLink;
};
//# sourceMappingURL=add.d.ts.map