/**
 * Get details of an "upload".
 *
 * Required delegated capability proofs: `upload/get`
 *
 * @param {import('../types.js').InvocationConfig} conf Configuration
 * for the UCAN invocation. An object with `issuer`, `with` and `proofs`.
 *
 * The `issuer` is the signing authority that is issuing the UCAN
 * invocation(s). It is typically the user _agent_.
 *
 * The `with` is the resource the invocation applies to. It is typically the
 * DID of a space.
 *
 * The `proofs` are a set of capability delegations that prove the issuer
 * has the capability to perform the action.
 *
 * The issuer needs the `upload/get` delegated capability.
 * @param {import('multiformats/link').UnknownLink} root Root data CID for the DAG that was stored.
 * @param {import('../types.js').RequestOptions} [options]
 * @returns {Promise<import('../types.js').UploadGetSuccess>}
 */
export function get({ issuer, with: resource, proofs, audience }: import('../types.js').InvocationConfig, root: import('multiformats/link').UnknownLink, options?: import("../types.js").RequestOptions | undefined): Promise<import('../types.js').UploadGetSuccess>;
/** Returns the ability used by an invocation. */
export const ability: "upload/get";
export function input(root: import('multiformats/link').UnknownLink): {
    root: import("multiformats/link").UnknownLink;
};
//# sourceMappingURL=get.d.ts.map