/**
 * Remove an upload by root data CID.
 *
 * @param {import('../types.js').InvocationConfig} conf Configuration
 * for the UCAN invocation. An object with `issuer`, `with` and `proofs`.
 *
 * The `issuer` is the signing authority that is issuing the UCAN
 * invocation(s). It is typically the user _agent_.
 *
 * The `with` is the resource the invocation applies to. It is typically the
 * DID of a space.
 *
 * The `proofs` are a set of capability delegations that prove the issuer
 * has the capability to perform the action.
 *
 * The issuer needs the `upload/remove` delegated capability.
 * @param {import('multiformats').UnknownLink} root Root data CID to remove.
 * @param {import('../types.js').RequestOptions} [options]
 */
export function remove({ issuer, with: resource, proofs, audience }: import('../types.js').InvocationConfig, root: import('multiformats').UnknownLink, options?: import("../types.js").RequestOptions | undefined): Promise<import("@web3-storage/capabilities/types").UploadAddSuccess>;
/** Returns the ability used by an invocation. */
export const ability: "upload/remove";
export function input(root: import('multiformats').UnknownLink): {
    root: import("multiformats").UnknownLink;
};
//# sourceMappingURL=remove.d.ts.map